@@ -22,6 +22,21 @@ def humanize_bool(setting: bool) -> str:
     return "✅ On" if setting else "❌ Off"
 
 
+def award_line(award: dict[str, Any]) -> str:
+    kind = "every" if award["repeating"] else "after"
+    give_or_take = "take" if award["remove"] else "give"
+    verified_only = "verified only" if award["verified_only"] else ""
+    unverified_only = "unverified only" if award["unverified_only"] else ""
+    verify_status = (
+        f" ({verified_only}{unverified_only}) " if verified_only or unverified_only else " "
+    )
+    return (
+        f"• **ID {award['id']}** — _{kind} {award['count']} games_ "
+        f"— {give_or_take} `@{award['role']}`{verify_status}"
+        f"— {award['message']}"
+    )
+
+
 class AdminAction(BaseAction):
     def __init__(self, bot: SpellBot, interaction: discord.Interaction):
         super().__init__(bot, interaction)
@@ -62,6 +77,7 @@ class AdminAction(BaseAction):
             update_channel_settings(channel, channel_settings, "unverified_only")
             update_channel_settings(channel, channel_settings, "verified_only")
             update_channel_settings(channel, channel_settings, "voice_category")
+            update_channel_settings(channel, channel_settings, "show_points")
             if channel_settings:
                 all_default = False
                 deets = ", ".join(
@@ -108,14 +124,7 @@ class AdminAction(BaseAction):
         description = ""
         for award in guild.get("awards", []):
             has_at_least_one_award = True
-            kind = "every" if award["repeating"] else "after"
-            give_or_take = "take" if award["remove"] else "give"
-            next_line = (
-                f"• **ID {award['id']}** — "
-                f"_{kind} {award['count']} games_"
-                f" — {give_or_take} `@{award['role']}`"
-                f" — {award['message']}\n"
-            )
+            next_line = f"{award_line(award)}\n"
             if len(description) + len(next_line) >= EMBED_DESCRIPTION_SIZE_LIMIT:
                 embed.description = description
                 embeds.append(embed)
@@ -161,10 +170,6 @@ class AdminAction(BaseAction):
             name="Public Links",
             value=humanize_bool(guild["show_links"]),
         )
-        embed.add_field(
-            name="Show Points on Games",
-            value=humanize_bool(guild["show_points"]),
-        )
         embed.add_field(
             name="Create Voice Channels",
             value=humanize_bool(guild["voice_create"]),
@@ -209,6 +214,17 @@ class AdminAction(BaseAction):
     ) -> None:
         repeating = bool(options.get("repeating", False))
         remove = bool(options.get("remove", False))
+        verified_only = bool(options.get("verified_only", False))
+        unverified_only = bool(options.get("unverified_only", False))
+
+        if verified_only and unverified_only:
+            await safe_send_channel(
+                self.interaction,
+                "Your award can't be both verified and unverifed only.",
+                ephemeral=True,
+            )
+            return
+
         max_message_len = GuildAward.message.property.columns[0].type.length  # type: ignore
         if len(message) > max_message_len:
             await safe_send_channel(
@@ -217,6 +233,7 @@ class AdminAction(BaseAction):
                 ephemeral=True,
             )
             return
+
         if count < 1:
             await safe_send_channel(
                 self.interaction,
@@ -224,29 +241,22 @@ class AdminAction(BaseAction):
                 ephemeral=True,
             )
             return
-        if await self.services.guilds.has_award_with_count(count):
-            await safe_send_channel(
-                self.interaction,
-                "There's already an award for players who reach that many games.",
-                ephemeral=True,
-            )
-            return
-        await self.services.guilds.award_add(
+
+        award = await self.services.guilds.award_add(
             count,
             role,
             message,
             repeating=repeating,
             remove=remove,
+            verified_only=verified_only,
+            unverified_only=unverified_only,
         )
+
         embed = Embed()
         embed.set_thumbnail(url=self.settings.ICO_URL)
         embed.set_author(name="Award added!")
-        every_or_after = "every" if repeating else "after"
-        give_or_take = "take" if remove else "give"
-        description = (
-            f"• _{every_or_after} {count} games_ — {give_or_take} `@{role}`"
-            f" — {message}\n\nYou can view all awards with the `/set awards` command."
-        )
+        line = award_line(award)
+        description = f"{line}\n\nYou can view all awards with the `/set awards` command."
         embed.description = description
         embed.color = self.settings.EMBED_COLOR
         await safe_send_channel(self.interaction, embed=embed, ephemeral=True)
@@ -276,12 +286,6 @@ class AdminAction(BaseAction):
         view = SetupView(self.bot)
         await safe_update_embed_origin(self.interaction, embed=embed, view=view)
 
-    async def toggle_show_points(self):
-        await self.services.guilds.toggle_show_points()
-        embed = await self._build_setup_embed()
-        view = SetupView(self.bot)
-        await safe_update_embed_origin(self.interaction, embed=embed, view=view)
-
     async def toggle_voice_create(self):
         await self.services.guilds.toggle_voice_create()
         embed = await self._build_setup_embed()
@@ -336,3 +340,19 @@ class AdminAction(BaseAction):
             f"Voice category prefix for this channel has been set to: {name}",
             ephemeral=True,
         )
+
+    async def set_delete_expired(self, value: bool):
+        name = await self.services.channels.set_delete_expired(self.interaction.channel_id, value)
+        await safe_send_channel(
+            self.interaction,
+            f"Delete expired setting for this channel has been set to: {name}",
+            ephemeral=True,
+        )
+
+    async def set_show_points(self, value: bool):
+        name = await self.services.channels.set_show_points(self.interaction.channel_id, value)
+        await safe_send_channel(
+            self.interaction,
+            f"Show points setting for this channel has been set to: {name}",
+            ephemeral=True,
+        )
