@@ -96,10 +96,20 @@ class AdminCog(commands.Cog):
         message: str,
         repeating: Optional[bool] = False,
         remove: Optional[bool] = False,
+        verified_only: Optional[bool] = False,
+        unverified_only: Optional[bool] = False,
     ) -> None:
         add_span_context(interaction)
         async with AdminAction.create(self.bot, interaction) as action:
-            await action.award_add(count, str(role), message, repeating=repeating, remove=remove)
+            await action.award_add(
+                count,
+                str(role),
+                message,
+                repeating=repeating,
+                remove=remove,
+                verified_only=verified_only,
+                unverified_only=unverified_only,
+            )
 
     @award_group.command(
         name="delete",
@@ -182,6 +192,28 @@ class AdminCog(commands.Cog):
         async with AdminAction.create(self.bot, interaction) as action:
             await action.set_voice_category(prefix)
 
+    @set_group.command(
+        name="delete_expired",
+        description="Set the option for deleting expired games in this channel.",
+    )
+    @app_commands.describe(setting="Setting")
+    @tracer.wrap(name="interaction", resource="set_delete_expired")
+    async def delete_expired(self, interaction: discord.Interaction, setting: bool) -> None:
+        add_span_context(interaction)
+        async with AdminAction.create(self.bot, interaction) as action:
+            await action.set_delete_expired(setting)
+
+    @set_group.command(
+        name="show_points",
+        description="Set the option for showing points on games in this channel.",
+    )
+    @app_commands.describe(setting="Setting")
+    @tracer.wrap(name="interaction", resource="set_show_points")
+    async def show_points(self, interaction: discord.Interaction, setting: bool) -> None:
+        add_span_context(interaction)
+        async with AdminAction.create(self.bot, interaction) as action:
+            await action.set_show_points(setting)
+
 
 async def setup(bot: SpellBot):  # pragma: no cover
     await bot.add_cog(AdminCog(bot), guild=bot.settings.GUILD_OBJECT)
