@@ -55,6 +55,11 @@ class GameFormat(Enum):
     TWO_HEADED_GIANT = FormatDetails(players=4)
     PAUPER = FormatDetails(players=2)
     PIONEER = FormatDetails(players=2)
+    EDH_MAX = FormatDetails(players=4)
+    EDH_HIGH = FormatDetails(players=4)
+    EDH_MID = FormatDetails(players=4)
+    EDH_LOW = FormatDetails(players=4)
+    EDH_BATTLECRUISER = FormatDetails(players=4)
 
 
 class Game(Base):
@@ -216,7 +221,7 @@ class Game(Base):
                     "\n\nYou can also [jump to the original game post]"
                     f"({self.jump_link}) in <#{self.channel_xid}>."
                 )
-            elif self.guild.show_points:
+            elif self.channel.show_points:
                 description += "\n\nWhen your game is over use the drop down to report your points."
         if self.guild.motd:
             description += f"\n\n{self.guild.motd}"
