@@ -61,11 +61,6 @@ class GuildsService:
         assert self.guild
         return self.guild.voice_create
 
-    @sync_to_async()
-    def should_show_points(self) -> bool:
-        assert self.guild
-        return self.guild.show_points
-
     @sync_to_async()
     def set_motd(self, message: Optional[str] = None) -> None:
         if message:
@@ -81,12 +76,6 @@ class GuildsService:
         self.guild.show_links = not self.guild.show_links  # type: ignore
         DatabaseSession.commit()
 
-    @sync_to_async()
-    def toggle_show_points(self) -> None:
-        assert self.guild
-        self.guild.show_points = not self.guild.show_points  # type: ignore
-        DatabaseSession.commit()
-
     @sync_to_async()
     def toggle_voice_create(self) -> None:
         assert self.guild
@@ -142,10 +131,12 @@ class GuildsService:
         role: str,
         message: str,
         **options: Optional[bool],
-    ) -> int:
+    ) -> dict[str, Any]:
         assert self.guild
         repeating = bool(options.get("repeating", False))
         remove = bool(options.get("remove", False))
+        verified_only = bool(options.get("verified_only", False))
+        unverified_only = bool(options.get("unverified_only", False))
         award = GuildAward(
             guild_xid=self.guild.xid,
             count=count,
@@ -153,10 +144,12 @@ class GuildsService:
             message=message,
             repeating=repeating,
             remove=remove,
+            verified_only=verified_only,
+            unverified_only=unverified_only,
         )  # type: ignore
         DatabaseSession.add(award)
         DatabaseSession.commit()
-        return award.id
+        return award.to_dict()
 
     @sync_to_async
     def award_delete(self, guild_award_id: int):
